package com.citrix.browser.analytics

import android.content.Context
import com.citrix.util.Util
import com.citrix.worx.sdk.MDXApplication
import com.google.firebase.crashlytics.FirebaseCrashlytics

object CrashlyticsUtil {
    // Custom keys for crashlytics
    private const val KEY_CUSTOMER_ID = "Customer ID"
    private const val KEY_IS_SECUREHUB_INSTALLED = "SecureHub Installed"
    private const val KEY_IS_SECUREHUB_ENROLLED = "SecureHub Enrolled"
    private const val KEY_SECUREHUB_VERSION = "SecureHub Version"
    private const val SECUREHUB_PACKAGE_NAME = "com.zenprise"
    private const val KEY_IS_SHARED_DEVICE = "Shared Device"

    private val crashlytics = FirebaseCrashlytics.getInstance();
    /**
     * Adds some custom key values to crashlytics.
     * Purpose of adding these keys is to analyse crash.
     *
     * @param context
     */
    @JvmStatic
    fun addCustomKeysWithCrashlytics(context: Context) {
        val emailAddress = Util.getEmailAddress(context)
        // Add customer id
        crashlytics.setCustomKey(KEY_CUSTOMER_ID, Util.getDomainFromEmail(emailAddress))
        // Add environment info
        crashlytics.setCustomKey(KEY_IS_SECUREHUB_INSTALLED, Util.isInstalledOnDevice(context, SECUREHUB_PACKAGE_NAME))
        crashlytics.setCustomKey(KEY_SECUREHUB_VERSION, Util.getAppVersion(context, SECUREHUB_PACKAGE_NAME))
        crashlytics.setCustomKey(KEY_IS_SECUREHUB_ENROLLED, MDXApplication.isManaged(context))
        crashlytics.setCustomKey(KEY_IS_SHARED_DEVICE, Util.isSharedDevice(context))
    }
}