package com.citrix.browser.baidu

import android.app.Activity
import android.app.Dialog
import android.graphics.Color
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.view.WindowManager
import android.webkit.WebChromeClient
import android.webkit.WebView
import android.webkit.WebViewClient
import android.widget.ProgressBar
import androidx.fragment.app.DialogFragment
import com.citrix.browser.R

import kotlinx.android.synthetic.main.baidu_decline_compliance_dialog.view.*
import kotlinx.android.synthetic.main.baidu_legal_compliance_dialog.view.*

class BaiduLegalComplianceDialogFragment : DialogFragment() {

    private lateinit var mParentView: View
    private var mLayoutResourceId = 0
    private var mLegalComplianceHeading = ""
    private var mLegalComplianceUrl = ""
    var mAcceptClickListener: (() -> Unit)? = null
    private lateinit var mWebView: WebView
    private lateinit var mProgressBar: ProgressBar

    companion object {
        const val TAG = "BaiduLegalComplianceDialogFragment"
        private const val LAYOUT_RESOURCE_ID = "layoutResourceId"
        private const val LEGAL_COMPLIANCE_HEADING = "legalComplianceHeading"
        private const val LEGAL_COMPLIANCE_URL = "legalComplianceUrl"

        @JvmStatic
        fun newInstance(
            layoutResourceId: Int,
            legalComplianceHeading: String,
            legalComplianceURL: String
        ): BaiduLegalComplianceDialogFragment {
            val fragment = BaiduLegalComplianceDialogFragment()
            val args = Bundle().apply {
                putInt(LAYOUT_RESOURCE_ID, layoutResourceId)
                putString(LEGAL_COMPLIANCE_HEADING, legalComplianceHeading)
                putString(LEGAL_COMPLIANCE_URL, legalComplianceURL)
            }
            fragment.arguments = args
            return fragment
        }
    }

    override fun onCreateDialog(savedInstanceState: Bundle?): Dialog {
        setStyle(STYLE_NO_FRAME, R.style.Theme_AppCompat_NoActionBar)

        return object : Dialog(activity as Activity, theme) {
            override fun onBackPressed() {
                showDeclineComplianceDialog()
            }
        }
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        arguments?.let {
            mLayoutResourceId = it.getInt(LAYOUT_RESOURCE_ID)
            mLegalComplianceHeading = it.getString(LEGAL_COMPLIANCE_HEADING) ?: ""
            mLegalComplianceUrl = it.getString(LEGAL_COMPLIANCE_URL) ?: ""
        }
    }

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View? {
        mParentView = inflater.inflate(mLayoutResourceId, container, false)
        mWebView = mParentView.compliance_page_wv
        mProgressBar = mParentView.webview_progress
        setDataUsingArguments()
        initClickListeners()
        return mParentView
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        dialog?.window?.addFlags(WindowManager.LayoutParams.FLAG_DRAWS_SYSTEM_BAR_BACKGROUNDS)
        dialog?.window?.statusBarColor = Color.WHITE
    }

    private fun setDataUsingArguments() {
        mParentView.legal_compliance_header_tv.text = mLegalComplianceHeading
        setupComplianceWebView()
    }

    private fun initClickListeners() {
        mParentView.accept_compliance_btn.setOnClickListener {
            mAcceptClickListener?.invoke()
            dismiss()
        }
        mParentView.decline_compliance_btn.setOnClickListener {
            showDeclineComplianceDialog()
        }
    }

    private fun showDeclineComplianceDialog() {
        val (dialogView: View, alertDialog) = BaiduStoreHelper.showAlertDialog(
            activity = activity as Activity,
            dialogLayoutResource = R.layout.baidu_decline_compliance_dialog
        )
        dialogView.cancel_textview.setOnClickListener {
            alertDialog.dismiss()
        }
        dialogView.warning_message_textview.text =
            getString(R.string.privacy_policy_not_accepted_message)
        dialogView.quit_app_textview.setOnClickListener {
            alertDialog.dismiss()
            if (activity != null) {
                activity!!.finish()
            }
        }
    }

    private fun setupComplianceWebView() {
        mWebView.isVerticalScrollBarEnabled = true
        mWebView.requestFocus()
        mWebView.settings.defaultTextEncodingName = "utf-8"
        mWebView.loadUrl(mLegalComplianceUrl)

        mWebView.webViewClient = object : WebViewClient() {
            override fun onPageFinished(view: WebView?, url: String?) {
                super.onPageFinished(view, url)
                mProgressBar.visibility = View.GONE
            }
        }
        mWebView.webChromeClient = object : WebChromeClient() {
            override fun onProgressChanged(view: WebView?, newProgress: Int) {
                super.onProgressChanged(view, newProgress)
                mProgressBar.visibility = View.VISIBLE
                mProgressBar.progress = newProgress
            }
        }
    }
}