package com.citrix.browser.baidu

import android.app.Activity
import android.app.AlertDialog
import android.content.SharedPreferences
import android.preference.PreferenceManager
import android.view.LayoutInflater
import android.view.View
import androidx.fragment.app.Fragment
import androidx.fragment.app.FragmentManager
import androidx.fragment.app.FragmentTransaction
import com.citrix.browser.BuildConfig
import com.citrix.browser.R

object BaiduStoreHelper {

    private const val PRIVACY_POLICY_KEY = "privacyPolicyKey"

    @JvmStatic
    fun shouldShowLegalComplianceDialog(activity: Activity) =
        isThisFreshAppInstall(activity) && isAppInstalledFromBaiduStore() && !privacyPolicyAccepted(
            activity
        )

    @JvmStatic
    fun isThisFreshAppInstall(activity: Activity): Boolean {
        val firstInstallTime = getFirstInstallTime(activity)
        val lastUpdateTime = getLastUpdateTime(activity)
        return firstInstallTime == lastUpdateTime
    }

    @JvmStatic
    fun getFirstInstallTime(activity: Activity) =
        activity.packageManager.getPackageInfo(activity.packageName, 0).firstInstallTime

    @JvmStatic
    fun getLastUpdateTime(activity: Activity) =
        activity.packageManager.getPackageInfo(activity.packageName, 0).lastUpdateTime

    @JvmStatic
    fun isAppInstalledFromBaiduStore(): Boolean {
        return BuildConfig.IS_BAIDU_STORE
    }

    @JvmStatic
    fun privacyPolicyAccepted(activity: Activity): Boolean {
        val sharedPreference = getDefaultSharedPreference(activity)
        return sharedPreference.getBoolean(PRIVACY_POLICY_KEY, false)
    }

    private fun updatePrivacyPolicyPreference(activity: Activity) {
        PreferenceManager.getDefaultSharedPreferences(activity).edit().apply {
            putBoolean(PRIVACY_POLICY_KEY, true)
            apply()
        }
    }

    @JvmStatic
    fun getDefaultSharedPreference(activity: Activity): SharedPreferences {
        return PreferenceManager.getDefaultSharedPreferences(activity)
    }

    @JvmStatic
    fun showLegalComplianceDialog(
            activity: Activity,
            fragmentManager: FragmentManager,
            onAcceptButtonClick: () -> Unit
    ) {
        val ft: FragmentTransaction = fragmentManager.beginTransaction()
        val prev: Fragment? =
            fragmentManager.findFragmentByTag(BaiduLegalComplianceDialogFragment.TAG)
        if (prev != null) {
            ft.remove(prev)
        }
        ft.addToBackStack(null)
        val heading = activity.getString(R.string.legal_compliance_heading)
        val url = activity.getString(R.string.privacy_policies_url)
        val legalComplianceDialogFragment = BaiduLegalComplianceDialogFragment.newInstance(
            layoutResourceId = R.layout.baidu_legal_compliance_dialog,
            legalComplianceHeading = heading,
            legalComplianceURL = url
        )
        legalComplianceDialogFragment.mAcceptClickListener = {
            updatePrivacyPolicyPreference(activity)
            onAcceptButtonClick.invoke()
        }
        legalComplianceDialogFragment.show(ft, BaiduLegalComplianceDialogFragment.TAG)
    }

    fun showAlertDialog(
        activity: Activity,
        dialogLayoutResource: Int
    ): Pair<View, AlertDialog> {
        val inflater = LayoutInflater.from(activity)
        val dialogView: View = inflater.inflate(dialogLayoutResource, null)
        val dialogBuilder = AlertDialog.Builder(activity)
        dialogBuilder.setView(dialogView)
        val alertDialog: AlertDialog = dialogBuilder.create()
        alertDialog.setCancelable(false)
        alertDialog.setCanceledOnTouchOutside(false)
        if (!activity.isFinishing) {
            alertDialog.show()
        }
        return Pair(dialogView, alertDialog)
    }
}