package com.citrix.browser.mvpn

import android.app.Notification
import android.app.NotificationManager
import android.content.Context
import android.content.Intent
import androidx.annotation.VisibleForTesting
import androidx.core.app.NotificationCompat
import com.citrix.Log
import com.citrix.browser.R
import com.citrix.mweutils.isWorkspaceWorkProfileMode
import com.citrix.util.Constants
import com.citrix.util.Util
import com.microsoft.intune.mam.client.app.MAMPendingIntent

internal object TunnelNotificationUtility {

    @VisibleForTesting
    const val CLICK_NOTIFICATION_ACTION = "tunnel_expiry_click_notification"

    @VisibleForTesting
    fun makeTunnelExpiryNotification(context: Context): Notification {
        Log.d(TunnelConstant.TAG, "Making a notification to indicate tunnel expiry")
        val clickIntent = Intent()
        clickIntent.setClass(context, TunnelExpiryActivity::class.java)
        clickIntent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
        clickIntent.action = CLICK_NOTIFICATION_ACTION

        val res = context.resources
        val isMWEMode = isWorkspaceWorkProfileMode(context)

        val title = res.getString(R.string.tunnel_notification_title)
        val builder = NotificationCompat.Builder(context, Util.getDefaultNotificationChannelId())
        builder.setContentTitle(title)
        builder.setAutoCancel(true)
        builder.setSmallIcon(R.mipmap.ic_launcher_round)

        val pendingClickIntent = MAMPendingIntent.getActivity(
            context, 0, clickIntent, 0
        )
        builder.setContentIntent(pendingClickIntent)
        when (isMWEMode) {
            true -> builder.setContentText(res.getString(R.string.tunnel_notification_content_MWE))
            false -> builder.setContentText(res.getString(R.string.tunnel_notification_content))
        }
        return builder.build()
    }

    @Synchronized
    fun notifyTunnelExpiry(context: Context) {
        val notification= makeTunnelExpiryNotification(context)
        notifyUser(context, notification)
    }

    @VisibleForTesting
    fun notifyUser(context: Context, notification: Notification) {
        Log.d(TunnelConstant.TAG, "Notifying user of tunnel expiry")
        val nm = context.getSystemService(Context.NOTIFICATION_SERVICE) as NotificationManager
        nm.notify(Constants.TUNNEL_EXPIRY_NOTIFICATION_ID, notification)
    }
}