package com.citrix.mvpn

import android.os.Handler
import android.os.Message
import com.citrix.Log
import com.citrix.mvpn.api.ResponseStatusCode

class TunnelHandler internal constructor(private val mCallback: Callback?) :
    Handler() {
    override fun handleMessage(msg: Message) {
        val responseStatusCode = ResponseStatusCode.fromId(msg.what)
        val retMessage = Message()
        Log.i(TunnelConstants.TAG, "In handle message")
        val response: Int
        response = when (responseStatusCode) {
            ResponseStatusCode.START_TUNNEL_SUCCESS -> {
                Log.i(TunnelConstants.TAG, "TunnelHandler.handleMessage(), Tunnel started successfully!!!")
                SUCCESS
            }
            ResponseStatusCode.START_TUNNEL_FAILED -> {
                Log.e(TunnelConstants.TAG, "TunnelHandler.handleMessage(), Failed to start tunnel!!!")
                FAILED
            }
            ResponseStatusCode.TUNNEL_ALREADY_RUNNING -> {
                Log.i(TunnelConstants.TAG, "TunnelHandler.handleMessage(), " +
                        "Tunnel is already running.")
                SUCCESS
            }
            ResponseStatusCode.SESSION_EXPIRED -> {
                Log.i(TunnelConstants.TAG, "TunnelHandler.handleMessage(), " +
                        "Session Expired!!!")
                SESSION_EXPIRED
            }
            ResponseStatusCode.FOUND_LEGACY_MODE -> {
                Log.e(TunnelConstants.TAG, "TunnelHandler.handleMessage(), " +
                        "Cannot start tunnel for Legacy ManagementMode!!!")
                FAILED
            }
            ResponseStatusCode.FOUND_NON_WEBSSO_MODE -> {
                Log.e(TunnelConstants.TAG, "TunnelHandler.handleMessage(), " +
                        "Cannot start tunnel for NetworkAccess mode other than Tunneled - Web SSO!!!")
                FAILED
            }
            ResponseStatusCode.FOUND_NON_MANAGED_APP -> {
                Log.i(TunnelConstants.TAG,
                    "TunnelHandler.handleMessage(), Could not retrieve policies!!! \n " +
                            "This could be because of the following reasons: \n\t " +
                            "1. SecureHub is not installed.\n\t " +
                            "2. SecureHub enrollment is not completed.\n\t " +
                            "3. App is not managed through CEM.")
                FAILED
            }
            ResponseStatusCode.NO_NETWORK_CONNECTION -> {
                Log.e(TunnelConstants.TAG, "TunnelHandler.handleMessage(), " +
                        "Failed to start tunnel. No Network!!!")
                FAILED
            }
            else -> {
                Log.e(TunnelConstants.TAG, "TunnelHandler.handleMessage(), " +
                        "Unknown responseStatusCode : $responseStatusCode")
                FAILED
            }
        }
        retMessage.what = response
        mCallback?.handleMessage(retMessage)
    }

    companion object {
        const val FAILED = -1
        const val SUCCESS = 0
        const val SESSION_EXPIRED = 1
    }

}