package com.citrix.mvpn

import android.content.Context
import android.os.Looper
import android.webkit.WebView
import android.webkit.WebViewClient

import com.citrix.Log
import com.citrix.mdx.sdk.MDXProvider
import com.citrix.mvpn.api.MicroVPNSDK
import com.citrix.mvpn.exception.ClientConfigurationException
import com.citrix.mvpn.exception.MvpnException
import com.citrix.mvpn.exception.NetworkTunnelNotStartedException

import java.io.IOException
import java.net.URL
import java.net.URLConnection

object TunnelUtility {

    @JvmStatic
    val isMainThread: Boolean
        get() = Looper.getMainLooper().thread.id == Thread.currentThread().id

    @JvmStatic
    @Throws(IOException::class)
    fun tunnelUrlConnection(context: Context, url: URL): URLConnection? {
        val urlConnection: URLConnection
        try {
            urlConnection = MicroVPNSDK.createURLConnection(context, url)
        } catch (e: ClientConfigurationException) {
            Log.e(
                TunnelConstants.TAG,
                "ClientConfigurationException occurred while creating TunnelUrlConnection, $e"
            )
            throw IOException("ClientConfigurationException occurred")
        } catch (e: NetworkTunnelNotStartedException) {
            Log.e(
                TunnelConstants.TAG,
                "NetworkTunnelNotStartedException occurred while creating TunnelUrlConnection, $e"
            )
            throw IOException("NetworkTunnelNotStartedException occurred")
        }

        return urlConnection
    }

    @JvmStatic
    fun enableWebViewTunnelling(
        context: Context,
        webView: WebView,
        webViewClient: WebViewClient?
    ): Boolean {
        var enabled = false
        try {
            if (null != webViewClient) {
                MicroVPNSDK
                    .enableWebViewObjectForNetworkTunnel(context, webView, webViewClient)
            } else {
                MicroVPNSDK.enableWebViewObjectForNetworkTunnel(context, webView)
            }
            enabled = true
        } catch (nse: NetworkTunnelNotStartedException) {
            Log.e(
                TunnelConstants.TAG,
                "NetworkTunnelNotStartedException occurred while enabling WebView tunnelling, ${nse.message}"
            )
        } catch (e: MvpnException) {
            Log.e(
                TunnelConstants.TAG,
                "MvpnException occurred while enabling WebView tunnelling, ${e.message}"
            )
        }

        return enabled
    }

    @JvmStatic
    fun canTunnel(context: Context): Boolean {
        return MicroVPNSDK.isWebSSOEnabled(context) && MicroVPNSDK.isSDKMode(context);
    }

}
