package com.citrix.mweutils


import android.annotation.TargetApi
import android.app.admin.DevicePolicyManager
import android.content.Context
import android.os.Build

internal const val PACKAGE_WORK_PROFILE_GOOGLE = "com.google.android.apps.work.clouddpc"

/**
 * this api validates, if Android work profile is setup through Citrix Workspace or not
 * @param context
 * @return true, if work profile is setup with Citrix Workspace, false otherwise
 */
@TargetApi(Build.VERSION_CODES.LOLLIPOP)
fun isWorkspaceWorkProfileMode(context: Context): Boolean {
    val devicePolicyManager = context.getSystemService(Context.DEVICE_POLICY_SERVICE) as DevicePolicyManager
    val activeAdmins = devicePolicyManager.activeAdmins
    var isWorkspaceWorkProfileMode = false
    if (activeAdmins != null) {
        for (admin in activeAdmins) {
            if (admin.packageName == PACKAGE_WORK_PROFILE_GOOGLE &&
                devicePolicyManager.isProfileOwnerApp(admin.packageName)
            ) {
                isWorkspaceWorkProfileMode = true
                break
            }
        }
    }
    return isWorkspaceWorkProfileMode
}